@@ -80,6 +80,14 @@ class BBox:
         else:
             return NotImplemented
 
+    @property
+    def pmin(self) -> Point2D:
+        return Point2D(x=self.xmin, y=self.ymin)
+    
+    @property
+    def pmax(self) -> Point2D:
+        return Point2D(x=self.xmax, y=self.ymax)
+
     @classmethod
     def buffer(self, bbox: BBox) -> BBox:
         return bbox
@@ -259,6 +267,12 @@ class BBox:
     def within(self, obj) -> bool:
         return self.to_shapely().within(obj.to_shapely())
 
+    def resize(self, orig_frame_shape: list, new_frame_shape: list) -> BBox:
+        h, w = orig_frame_shape[:2]
+        target_h, target_w = new_frame_shape[:2]
+        w_scale, h_scale = target_w / w, target_h / h
+        return BBox(xmin=self.xmin*w_scale, ymin=self.ymin*h_scale, xmax=self.xmax*w_scale, ymax=self.ymax*h_scale)
+
     def rescale(self, target_shape: list, fixed_point: Point) -> BBox:
         if fixed_point.x < self.xmin or fixed_point.x > self.xmax or \
             fixed_point.y < self.ymin or fixed_point.y > self.ymax:
@@ -387,6 +401,22 @@ class BBox:
             logger.error(f'Expected len(img.shape) to be either 2 or 3. Encountered len(img.shape) == {len(img.shape)}')
             raise Exception
     
+    def crop_and_paste(self, src_img: np.ndarray, dst_img: np.ndarray, dst_bbox: BBox=None) -> np.ndarray:
+        self.check_bbox_in_frame(src_img.shape)
+        if dst_bbox is not None:
+            dst_bbox.check_bbox_in_frame(dst_img.shape)
+        else:
+            self.check_bbox_in_frame(dst_img.shape)
+        result = dst_img.copy()
+        cropped_img = self.crop_from(src_img)
+        if dst_bbox is not None:
+            if dst_bbox.shape != cropped_img.shape[:2]:
+                cropped_img = cv2.resize(src=cropped_img, dsize=(dst_bbox.width, dst_bbox.height))
+            result[int(dst_bbox.ymin):int(dst_bbox.ymax), int(dst_bbox.xmin):int(dst_bbox.xmax), :] = cropped_img
+        else:
+            result[int(self.ymin):int(self.ymax), int(self.xmin):int(self.xmax), :] = cropped_img
+        return result
+
     def crop_from_and_save_to(self, img: np.ndarray, save_path: str, overwrite: bool=False):
         cropped_region = self.crop_from(img=img)
         if file_exists(save_path) and not overwrite:
