@@ -95,6 +95,12 @@ class Keypoint2D:
     def origin(cls, x: float=0.0, y: float=0.0, v: int=0) -> Keypoint2D:
         return Keypoint2D(point=Point2D(x=x, y=y), visibility=v)
 
+    def resize(self, orig_frame_shape: list, new_frame_shape: list) -> Keypoint2D:
+        return Keypoint2D(
+            point=self.point.resize(orig_frame_shape=orig_frame_shape, new_frame_shape=new_frame_shape),
+            visibility=self.visibility
+        )
+
 class Keypoint3D:
     def __init__(self, point: Point3D, visibility: int):
         check_type(point, valid_type_list=[Point3D])
@@ -268,6 +274,31 @@ class Keypoint2D_List(BasicHandler['Keypoint2D_List', 'Keypoint2D']):
 
     def to_point_list(self) -> Point2D_List:
         return Point2D_List([kpt.point for kpt in self])
+    
+    @classmethod
+    def from_point_list(cls, point_list: Point2D_List, visibility: List[int]=None) -> Keypoint2D_List:
+        if not isinstance(point_list, Point2D_List):
+            raise TypeError(f'type(point_list) != Point2D_List')
+        if isinstance(visibility, (list, tuple)):
+            if not isinstance(visibility[0], int):
+                raise TypeError('type(visibility) != List[int]')
+            if len(visibility) != len(point_list):
+                raise IndexError(f'len(visibility) == {len(visibility)} != {len(point_list)} == len(point_list)')
+            v_list = list(visibility)
+        elif isinstance(visibility, int):
+            v_list = [visibility]*len(point_list)
+        elif isinstance(visibility, float):
+            if not visibility.is_integer():
+                raise ValueError(f'type(visibility) == float and not visibility.is_integer()')
+            v_list = [int(visibility)]*len(point_list)
+        else:
+            raise TypeError(f'visibility of type {type(visibility).__name__} not supported.')
+        return Keypoint2D_List([Keypoint2D(point=point, visibility=v) for point, v in zip(point_list, v_list)])
+
+    def resize(self, orig_frame_shape: list, new_frame_shape: list) -> Keypoint2D_List:
+        return Keypoint2D_List(
+            [kpt.resize(orig_frame_shape=orig_frame_shape, new_frame_shape=new_frame_shape) for kpt in self]
+        )
 
 class Keypoint3D_List(BasicHandler['Keypoint3D_List', 'Keypoint3D']):
     def __init__(self, kpt_list: List[Keypoint3D]=None):
@@ -349,4 +380,24 @@ class Keypoint3D_List(BasicHandler['Keypoint3D_List', 'Keypoint3D']):
         return cls.from_numpy(arr=np.array(value_list), demarcation=demarcation)
 
     def to_point_list(self) -> Point3D_List:
-        return Point3D_List([kpt.point for kpt in self])
\ No newline at end of file
+        return Point3D_List([kpt.point for kpt in self])
+
+    @classmethod
+    def from_point_list(cls, point_list: Point3D_List, visibility: List[int]=None) -> Keypoint3D_List:
+        if not isinstance(point_list, Point3D_List):
+            raise TypeError(f'type(point_list) != Point3D_List')
+        if isinstance(visibility, (list, tuple)):
+            if not isinstance(visibility[0], int):
+                raise TypeError('type(visibility) != List[int]')
+            if len(visibility) != len(point_list):
+                raise IndexError(f'len(visibility) == {len(visibility)} != {len(point_list)} == len(point_list)')
+            v_list = list(visibility)
+        elif isinstance(visibility, int):
+            v_list = [visibility]*len(point_list)
+        elif isinstance(visibility, float):
+            if not visibility.is_integer():
+                raise ValueError(f'type(visibility) == float and not visibility.is_integer()')
+            v_list = [int(visibility)]*len(point_list)
+        else:
+            raise TypeError(f'visibility of type {type(visibility).__name__} not supported.')
+        return Keypoint3D_List([Keypoint3D(point=point, visibility=v) for point, v in zip(point_list, v_list)])
\ No newline at end of file
